VERSION 5.00
Begin VB.Form Form1 
   Caption         =   "Simple Light & AlphaBlending Tutorial"
   ClientHeight    =   4530
   ClientLeft      =   4845
   ClientTop       =   3075
   ClientWidth     =   5655
   LinkTopic       =   "Form1"
   ScaleHeight     =   4530
   ScaleWidth      =   5655
End
Attribute VB_Name = "Form1"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
'----------------------------------------------------------
' TrueVision Tutorials : Dynamic Lighting & Alpha Blending
'----------------------------------------------------------

' This tutorial shows you how to create a dynamic light and move it.
' A alphablended wall is also shown
'
' NOTE : You have to create materials & use TV_NORMAL_VERTEX to use dynamic lighting
'        Look at the tutorial in Form_Load

Public TV As New TrueVision8
Public Scene As New Scene8
Public Inp As New InputEngine8
Public Camera As New Camera8
Public Light As New LightEngine8 '-> LIGHTS

Public MatFactory As New MaterialFactory8 '-> MATERIALS

Public Mesh As Mesh8
Public Blended As Mesh8

'You can recognize lights by Light ID
Public LightID As Integer

Private Sub Form_Load()
 '1. Show the form in that the scene will be rendered.
    Form1.Show
    TV.DisplayFPS = True
    
    '2. Initialize the engine in windowed mode.
    '   Note that you have to use the Hwnd of the desired form or picturebox
    TV.Initialize Form1.hWnd
    
    '2b. Defines the data directory. Usually it's the application path
    TV.SetSearchDirectory App.Path
    
    '3. Create the room
    '3a : Create the mesh from the scene object
    Set Mesh = Scene.CreateMeshBuilder("Room")
    
    '3b : Add the walls to the room using the Mesh8.AddWall method
    '     We will set the texture later...
    '     Note that you should subdivide your too big faces so that
    '     Direct3D Lighting works better
    '     Here we have divided the room box in 10
    For i = 0 To 19
     Mesh.AddWall Nothing, -10, i * 5, -10, i * 5 + 5, 20
     Mesh.AddWall Nothing, 10, i * 5 + 5, 10, i * 5, 20
     Mesh.AddFloor Nothing, -10, i * 5, 10, i * 5 + 5, 0
     Mesh.AddFloor Nothing, -10, i * 5, 10, i * 5 + 5, 20
    Next i
     
     Mesh.AddWall Nothing, -10, 100, 10, 100, 20
     Mesh.AddWall Nothing, -10, 0, 10, 0, 20
            
    '3d : Load a brick texture. Note that TrueVision can load
    '     BMP, JPG, DDS, PNG, GIF picture files.
    Scene.LoadTexture "brick1.bmp", , , "BrickTexture"
    
    '3e : Apply the texture to the room
    Mesh.SetTexture GetTex("BrickTexture")
    
    '4 : Set the camera startpos
    Camera.SetCameraPosition 0, 10, 0
    Camera.SetCameraLookAt 0, 10, 1
    
    '5 ------------------------
    '  Lighting setup
    '--------------------------
    ' 1 : Use normal vertex for lightning.
    '     You MUST use this kind of vertexs.
    Mesh.SetVertexType TV_NORMAL_VERTEX
    
    ' 2 : Create a material for the corridor
    ' When you create a material with Quick function
    ' the given color is attribued to Ambient lighting
    ' (color without light) and (color with light)
    MatFactory.CreateMaterialQuick 0.2, 0.2, 0.2, 1, "Mat"
    
    'Then you have to set the diffuse color
    'Usually 1,1,1,1
    MatFactory.SetDiffuse GetMat("Mat"), 1, 1, 1, 1
    
    'Apply it to the corridor
    Mesh.SetMaterial GetMat("Mat")
    
    '3 Then let's compute the face normals
    '  so that the light engine computes the reflection vector.
    Mesh.ComputeNormals
    
    '4 Create the point light and get the Light ID
    '  NOTE You must give very high color values
    '  The Radius is the distance where the light doesn't lit anything more
    LightID = Light.CreatePointLight(Vector(0, 10, 10), 30, 0, 300, 0, 1)
    Light.SetLightAttenuation LightID, 1, 1, 1
    'Light.SetLightFalloff LightID, 0.5
    
    '------------------------------
    ' Alpha Blended Stuff
    '------------------------------
    ' For Alpha blended face, we needn't use lighting
    ' so let's use COLOR_VERTEX
    
    '1. Create the mesh
    Set Blended = Scene.CreateMeshBuilder("Blended")
    
    '2. Set the vertex format
    Blended.SetVertexType TV_COLOR_VERTEX
    
    '3. Set the blending mode. The ALPHA blending mode is selected by default
    'but you can choose other mode with the SetAlphaBlendingMode function.
    Blended.SetBlendingMode TV_BLEND_ALPHA
    
    '4. Create the wall
    Blended.AddWall Nothing, -10, 50, 10, 50, 20
    
    '5. Set the alpha factor of the mesh. Here we use 0.5
    ' Note you can apply a texture too.
    Blended.SetColor RGBA(1, 0, 0, 0.2)
    
    'Remarks : If you need to work with materials and alphablending,
    '          you have to set the SAME alpha blending factor in the
    '          different material color values.
    
    
    'The main game loop :
    Dim a As Single
    Do
      'Clear the screen. You must do this before rendering anything on the screen.
      TV.Clear
      
      'Call the room rendering method
      Scene.RenderAllMeshes
      
      'Render everything on the screen
      TV.RenderToScreen
      
      'Move the light
      a = a + TV.TimeElapsed * 0.001
      Light.SetLightPosition LightID, Vector(0, 10, Sin(a) * 50 + 50)
      
      'Move the scene according to the keyboard presses.
      
      If Inp.IsKeyPressed(TV_KEY_UP) = True Then Camera.MoveForward 20
      If Inp.IsKeyPressed(TV_KEY_DOWN) = True Then Camera.MoveForward -20
      If Inp.IsKeyPressed(TV_KEY_RIGHT) = True Then Camera.RotateCameraY -60
      If Inp.IsKeyPressed(TV_KEY_LEFT) = True Then Camera.RotateCameraY 60
      
    'Check the Escape Key that ends up the tutorial
    Loop Until Inp.IsKeyPressed(TV_KEY_ESCAPE) = True
    
    'Don't forget to shut down the engine
    Set TV = Nothing
    End
End Sub





